==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Werk</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Privé</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Overig</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Eén dag van tevoren</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Herinner me morgen</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Herinner me later</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 min. later</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 uur later</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 uur later</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Morgen</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Herinnering inplannen</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>van %1 tot %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Vandaag</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Eén dag van tevoren</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Sluiten</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Herinner me morgen</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Herinner me later</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Herinnering inplannen</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">van %1 tot %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Vandaag</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Morgen</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Werk</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Privé</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Overig</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Eén dag van tevoren</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Herinner me morgen</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Herinner me later</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 min. later</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 uur later</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 uur later</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Morgen</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Herinnering inplannen</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>van %1 tot %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Vandaag</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
